@@ -23,7 +23,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING, TypedDict
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.auth_manager.avp.entities import AvpEntities, get_action_id, get_entity_type
 from airflow.providers.amazon.aws.auth_manager.constants import (
     CONF_AVP_POLICY_STORE_ID_KEY,
@@ -32,6 +31,7 @@ from airflow.providers.amazon.aws.auth_manager.constants import (
     CONF_SECTION_NAME,
 )
 from airflow.providers.amazon.aws.hooks.verified_permissions import VerifiedPermissionsHook
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.utils.helpers import prune_dict
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -120,7 +120,7 @@ class AwsAuthManagerAmazonVerifiedPermissionsFacade(LoggingMixin):
                 "principal": {"entityType": get_entity_type(AvpEntities.USER), "entityId": user.get_id()},
                 "action": {
                     "actionType": get_entity_type(AvpEntities.ACTION),
-                    "actionId": get_action_id(entity_type, method),
+                    "actionId": get_action_id(entity_type, method, entity_id),
                 },
                 "resource": {"entityType": get_entity_type(entity_type), "entityId": entity_id or "*"},
                 "entities": {"entityList": entity_list},
@@ -281,7 +281,9 @@ class AwsAuthManagerAmazonVerifiedPermissionsFacade(LoggingMixin):
                 "principal": {"entityType": get_entity_type(AvpEntities.USER), "entityId": user.get_id()},
                 "action": {
                     "actionType": get_entity_type(AvpEntities.ACTION),
-                    "actionId": get_action_id(request["entity_type"], request["method"]),
+                    "actionId": get_action_id(
+                        request["entity_type"], request["method"], request.get("entity_id")
+                    ),
                 },
                 "resource": {
                     "entityType": get_entity_type(request["entity_type"]),
