@@ -21,7 +21,6 @@ from functools import cached_property
 from typing import TYPE_CHECKING, Any, ClassVar
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.comprehend import ComprehendHook
 from airflow.providers.amazon.aws.links.comprehend import (
     ComprehendDocumentClassifierLink,
@@ -34,6 +33,7 @@ from airflow.providers.amazon.aws.triggers.comprehend import (
 )
 from airflow.providers.amazon.aws.utils import validate_execute_complete_event
 from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.utils.timezone import utcnow
 
 if TYPE_CHECKING:
