@@ -21,10 +21,10 @@ from collections.abc import Sequence
 from enum import Enum
 from typing import TYPE_CHECKING, Any
 
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.glacier import GlacierHook
 from airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor
 from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
+from airflow.providers.common.compat.sdk import AirflowException
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -89,11 +89,10 @@ class GlacierJobOperationSensor(AwsBaseSensor[GlacierHook]):
             self.log.info("Job status: %s, code status: %s", response["Action"], response["StatusCode"])
             self.log.info("Job finished successfully")
             return True
-        elif response["StatusCode"] == JobStatus.IN_PROGRESS.value:
+        if response["StatusCode"] == JobStatus.IN_PROGRESS.value:
             self.log.info("Processing...")
             self.log.warning("Code status: %s", response["StatusCode"])
             return False
-        else:
-            raise AirflowException(
-                f"Sensor failed. Job status: {response['Action']}, code status: {response['StatusCode']}"
-            )
+        raise AirflowException(
+            f"Sensor failed. Job status: {response['Action']}, code status: {response['StatusCode']}"
+        )
