@@ -26,10 +26,10 @@ from typing import TYPE_CHECKING, Any
 from botocore import UNSIGNED
 from botocore.config import Config
 
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.utils import trim_none_values
+from airflow.providers.amazon.version_compat import NOTSET, ArgNotSet
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.utils.log.logging_mixin import LoggingMixin
-from airflow.utils.types import NOTSET, ArgNotSet
 
 if TYPE_CHECKING:
     from airflow.providers.common.compat.sdk import Connection
