@@ -27,6 +27,7 @@ from urllib.request import urlretrieve
 import boto3
 from botocore.exceptions import ClientError
 from opensearchpy import (
+    AuthenticationException,
     AuthorizationException,
     AWSV4SignerAuth,
     OpenSearch,
@@ -54,8 +55,8 @@ from airflow.providers.amazon.aws.sensors.opensearch_serverless import (
     OpenSearchServerlessCollectionActiveSensor,
 )
 from airflow.providers.amazon.aws.utils import get_botocore_version
-from airflow.providers.standard.operators.empty import EmptyOperator
 
+from tests_common.test_utils.compat import EmptyOperator
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
@@ -66,7 +67,11 @@ else:
     from airflow.models.baseoperator import chain  # type: ignore[attr-defined,no-redef]
     from airflow.models.dag import DAG  # type: ignore[attr-defined,no-redef,assignment]
     from airflow.sdk import Label  # type: ignore[attr-defined,no-redef]
-from airflow.utils.trigger_rule import TriggerRule
+try:
+    from airflow.sdk import TriggerRule
+except ImportError:
+    # Compatibility for Airflow < 3.1
+    from airflow.utils.trigger_rule import TriggerRule  # type: ignore[no-redef,attr-defined]
 
 from system.amazon.aws.utils import SystemTestContextBuilder
 
@@ -76,8 +81,9 @@ from system.amazon.aws.utils import SystemTestContextBuilder
 #   the Amazon Bedrock console and may take up to 24 hours to apply:
 #######################################################################
 
-CLAUDE_MODEL_ID = "anthropic.claude-v2"
+CLAUDE_MODEL_ID = "anthropic.claude-3-5-sonnet-20241022-v2:0"
 TITAN_MODEL_ID = "amazon.titan-embed-text-v1"
+ANTHROPIC_VERSION = "bedrock-2023-05-31"
 
 # Externally fetched variables:
 ROLE_ARN_KEY = "ROLE_ARN"
@@ -261,7 +267,7 @@ def create_vector_index(index_name: str, collection_id: str, region: str):
             response = oss_client.indices.create(index=index_name, body=json.dumps(index_config))
             log.info("Creating index: %s.", response)
             break
-        except AuthorizationException as e:
+        except (AuthorizationException, AuthenticationException) as e:
             # Index creation can take up to a minute and there is no (apparent?) way to check the current state.
             log.info(
                 "Access denied; policy permissions have likely not yet propagated, %s tries remaining.",
@@ -443,7 +449,6 @@ with DAG(
     dag_id=DAG_ID,
     schedule="@once",
     start_date=datetime(2021, 1, 1),
-    tags=["example"],
     catchup=False,
 ) as dag:
     test_context = sys_test_context_task()
@@ -482,7 +487,13 @@ with DAG(
     invoke_claude_completions = BedrockInvokeModelOperator(
         task_id="invoke_claude_completions",
         model_id=CLAUDE_MODEL_ID,
-        input_data={"max_tokens_to_sample": 4000, "prompt": f"\n\nHuman: {PROMPT}\n\nAssistant:"},
+        input_data={
+            "max_tokens": 4000,
+            "anthropic_version": ANTHROPIC_VERSION,
+            "messages": [
+                {"role": "user", "content": f"\n\nHuman: {PROMPT}\n\nAssistant:"},
+            ],
+        },
     )
     # [END howto_operator_invoke_claude_model]
 
